import java.io.*;
/**
* This example program reads lines of text from the console and
* writes them out to a file.
*/
public class TextRW {
	/**
	* Create a new TextRW object with which to read and write.
	* @param fn the name of the file to write.  
	*/
	public TextRW(String fn) throws IOException {
		/**
		* Open a connection to the file.
		* @param fn the name of the file to write
		*/
		File sink = new File(fn);
		sink.createNewFile();
		System.out.println("Created "+sink.getAbsolutePath());
		textWriter = new PrintWriter(new BufferedWriter(new FileWriter(sink)));
	}
	/**
	* Write one line on the output file.
	* @param line the line of text to write out
	*/
	public void writeOneLine(String s) {
		textWriter.println(s);
	}

	/**
	* Close the stream.
	*/
	public void close() throws IOException {
		textWriter.close();
	}
	/**
	* Test harness for this class.
	* @param arg arg[0] name of the file to read.  Defaults to sampleOut.txt if
	* not specified.
	*/
	public static void main(String[] arg) throws IOException {

		String name = "sampleOut.txt";
		if (arg.length > 0) {
			name = arg[0];
		}
		System.out.println("Opening "+name);
		TextRW tr = new TextRW(name);
		System.out.println("Writing "+name+" until you press return twice in a row.");
        BufferedReader console = new BufferedReader(new InputStreamReader(System.in));
		boolean oneBlank = false;
        while (true) {
            System.out.print("? ");
            String line = console.readLine();
            if (line == null || line.length() == 0) {
				if (oneBlank) {
					break;
				} else {
					oneBlank = true;
				}
			} else {
				tr.writeOneLine(line);
			}
		}
		tr.close();
	}
	
	//--------------
	
	PrintWriter textWriter;
	}
