import java.io.*;
/**
* This example program reads lines of text from a file and writes
* them on the console window.
*/
public class TextRead {
	/**
	* Create a new TextRead object with which to read a file.
	* @param fn the name of the file to read.  
	*/
	public TextRead(String fn) throws IOException {
		/**
		* Open a connection to the file as an InputStream, then create a BufferedReader
		* to actually read it with.
		*/
		InputStream in;
		in = new FileInputStream(fn);									// open a connection to the file
//		in = this.getClass().getClassLoader().getResourceAsStream(fn);	// or use the classpath to find the file
		textReader = new BufferedReader(new InputStreamReader(in));		// decorate the connection
		
//		textReader = new BufferedReader(new FileReader(fn));			// use an implicit input stream
	}
	/**
	* Read one line from the text file and return it as a String to the caller.
	* Note that the line might be null (at end of file), empty (0 characters) or 
	* blank (all whitespace).  Of course, it might also be a non-blank String with
	* some useful characters in it.
	* @return a String containing the next line or null if 
	* we are at the end of the file
	*/
	private String getNextLine() throws IOException {
		return textReader.readLine();
	}
	/**
	* Read one line from the text file and return it as a String to the caller.
	* Skip lines that are empty (0 characters) or that are blank (all
	* whitespace).
	* @return a String containing the next non-blank line or null if 
	* we are at the end of the file
	*/
	private String getNextNonBlankLine() throws IOException {
		String line = textReader.readLine();
		while (line != null && line.trim().length() == 0) {
			line = textReader.readLine();
		}
		return line;
	}
	/**
	* Close the stream.
	*/
	public void close() throws IOException {
		textReader.close();
	}
	/**
	* Test harness for this class.
	* @param arg arg[0] name of the file to read.  Defaults to sampleIn.txt if
	* not specified.
	*/
	public static void main(String[] arg) throws IOException {
		PrintWriter w = new PrintWriter(new OutputStreamWriter(System.out),true);
		String name = "sampleIn.txt";
		if (arg.length > 0) {
			name = arg[0];
		}
		w.println("Opening "+name);
		TextRead tr = new TextRead(name);
		w.println("Reading "+name+" (including blank lines)");
		String myLine = tr.getNextLine();
		while (myLine != null) {
			w.println(">> "+myLine);
			myLine = tr.getNextLine();
		}
		w.println("Done reading.");
		tr.close();
		
		w.println("Opening "+name);
		tr = new TextRead(name);
		w.println("Reading "+name+" (skipping blank lines)");
		myLine = tr.getNextNonBlankLine();
		while (myLine != null) {
			w.println(">> "+myLine);
			myLine = tr.getNextNonBlankLine();
		}
		w.println("Done reading.");
		w.close();
	}
	
	//--------------
	
	BufferedReader textReader;
	}
